const { typography, spacing, shadows, radii, transition } = require('../../src');
const { colors } = require('./colors');
const { alertVariants } = require('./components/alert');
const { badgeVariants } = require('./components/badge');
const { buttonVariants, buttonIconVariants } = require('./components/button');
const { cardStyles, cardVariants } = require('./components/card');
const { checkboxStyles } = require('./components/checkbox');
const { dividerStyles } = require('./components/divider');
const { inputStyles } = require('./components/input');
const { logoVariants } = require('./components/logo');
const { radioStyles } = require('./components/radio');
const { selectStyles } = require('./components/select');
const { switchStyles } = require('./components/switch');
const { tagStyles } = require('./components/tag');
const { tooltipStyles } = require('./components/tooltip');
const { modalStyles } = require('./components/modal');
const { progressStyles } = require('./components/progress');
const { popoverStyles } = require('./components/popover');
const { textStyles } = require('./components/text');
const { boneStyles } = require('./components/bone');
const { groupStyles } = require('./components/group');
const { wordmarkStyles } = require('./components/wordmark');
const { tableStyles } = require('./components/table');
const { sidebarStyles } = require('./components/sidebar');

// Adding aliases for easy consumption on the consumer side
colors.primary = colors['green-700'];
colors.secondary = colors['blue-500'];
colors.danger = colors['maple-500'];
colors.warning = colors['orange-500'];
colors.white = colors.white;
colors.textBody = colors['gray-700'];
colors.textHeading = colors['gray-1000'];
colors.textDimmed = colors['gray-500'];
colors.dimmed = colors['gray-50'];
colors.disabled = colors['gray-100'];

const theme = {
  breakpoints: ['601px', '1024px'],
  colors,
  fontFamily: typography.typeface,
  space: Object.values(spacing.scale),
  lineHeights: Object.values(spacing.scale),
  fontSizes: { ...typography.fontSizes, ...typography.fontSizeAliases },
  fontWeights: typography.weights,
  letterSpacings: [...Object.values(typography.letterSpacings)],
  shadows: Object.values(shadows.outer),
  innerShadows: Object.values(shadows.inner),
  innerShadowsN: Object.values(shadows.innerN),
  borderShadows: Object.values(shadows.border),
  radii: radii.values,
  transition: transition.durations,
  alertVariants,
  badgeVariants,
  buttonVariants,
  buttonIconVariants,
  cardStyles,
  cardVariants,
  checkboxStyles,
  dividerStyles,
  inputStyles,
  logoVariants,
  radioStyles,
  selectStyles,
  switchStyles,
  tagStyles,
  tooltipStyles,
  modalStyles,
  progressStyles,
  popoverStyles,
  textStyles,
  boneStyles,
  groupStyles,
  wordmarkStyles,
  tableStyles,
  sidebarStyles,
};

module.exports = JSON.stringify(theme);
